@@ -9,23 +9,9 @@ impl Connection {
      * See
      * [PQputCopyData](https://www.postgresql.org/docs/current/libpq-copy.html#LIBPQ-PQPUTCOPYDATA).
      */
+    #[deprecated(since="1.4.0", note="In v2, this function will take a &[u8], use v2::connection::put_copy_data instead")]
     pub fn put_copy_data(&self, buffer: &str) -> std::result::Result<(), String> {
-        log::trace!("Sending copy data");
-
-        let c_buffer = crate::ffi::to_cstr(buffer);
-
-        let success = unsafe {
-            pq_sys::PQputCopyData(self.into(), c_buffer.as_ptr(), buffer.len() as i32)
-        };
-
-        match success {
-            -1 => Err(self
-                .error_message()
-                .unwrap_or_else(|| "Unknow error".to_string())),
-            0 => Err("Full buffers".to_string()),
-            1 => Ok(()),
-            _ => unreachable!(),
-        }
+        crate::v2::connection::put_copy_data(self, buffer.as_bytes())
     }
 
     /**
@@ -66,6 +52,7 @@ impl Connection {
         let mut ptr = std::ptr::null_mut();
 
         let success = unsafe { pq_sys::PQgetCopyData(self.into(), &mut ptr, r#async as i32) };
+        let buffer = crate::ffi::from_raw(ptr);
 
         match success {
             -2 => Err(self
@@ -73,12 +60,7 @@ impl Connection {
                 .unwrap_or_else(|| "Unknow error".to_string())),
             -1 => Err("COPY is done".to_string()),
             0 => Err("COPY still in progress".to_string()),
-            nbytes => unsafe {
-                let buffer = std::slice::from_raw_parts(ptr as *const u8, nbytes as usize).to_vec();
-                pq_sys::PQfreemem(ptr as *mut std::ffi::c_void);
-
-                Ok(String::from_utf8_lossy(&buffer).to_string())
-            }
+            _ => Ok(buffer),
         }
     }
 }
